* This do-file produces the ideology validation shown in the first panel of 
* Figure A1 in the Appendix. 

*** This do-file re-creates the analysis in the paper using the Catalist dataset

* Open 1% sample from Catalist
use catalist2013_thin, clear

* Drop individuals who Catlist believes are likely dead or have a new record
* in another state
drop if sy_deadwood=="DEAD" | sy_deadwood=="PROBDEAD" | sy_deadwood=="POSSDEAD"

* Re-name state and district variables for merging 
ren state_name state
ren previous_congressionaldistrict district

* Drop individuals who Catalist did not place in a congressional district
drop if district==.

* Create ideology variable that is rounded to nearest integer. 
ren sy_ideologymodel ideology
replace ideology=round(ideology)
label variable ideology "Ideology"

* Collapse data, calculating mean ideology by state and district
collapse (mean) ideology, by(state district)

* Sort data for later merge and save as a temporary file
sort state district
save temp, replace

* Open Warshaw/Tausanovitch district ideology scores obtained from their website
insheet using "cd_estimates.csv", clear

* Reformat state and district variables for merging
tostring fips, replace
gen district=real(substr(fips,-2,.))
ren abb state

* Merge in district level means of Catalist ideology created above
sort state district
merge state district using temp
drop if _m<3

* Change direct of Warshaw/Tausanovitch ideology measure to match direction of 
* Catalist ideology measure
replace mrp_estimate=mrp_estimate*-1

* Produce correlation
corr mrp_estimate ideology

* Produce scatterplot with linear fit line and correlation
twoway scatter ideology mrp_estimate, msize(tiny) mc(gs10) || lfit ideology mrp_estimate, lc(black) aspect(1) legend(off) xtitle("Survey based ideology measure") ytitle("Catalist based ideology measure") text( 45 .4 "r = .92")
graph export district_validation.pdf, replace

