*** This do-file re-creates the analysis in the paper using the Catalist dataset

* Open 1% sample from Catalist
use catalist2013_thin, clear

* Drop individuals who Catlist believes are likely dead or have a new record
* in another state
drop if sy_deadwood=="DEAD" | sy_deadwood=="PROBDEAD" | sy_deadwood=="POSSDEAD"

* Re-name state and district variables for merging 
ren state_name stateabb
ren previous_congressionaldistrict district

*Merge in DW-Nominate scores for 112th congress
sort stateabb district
merge m:1 stateabb district using nom112

* Drop observations for whom a merge was unsuccessful. These are observations where
* catalist did not have information related to their congressional district during
* the 112th Congress
keep if _m==3
drop _m

* Recode the variable for party of incumbent so that 0 is Republican and 1 is Democrat
recode party 200=0 100=1

* Re-scale the first dimension dw-nominate score for each house member on scale from 0 to 100
gen nominate=((dwnom1*-1)+.988)/1.732
replace nominate=nominate*100

* Create ideology variable that is rounded to nearest integer. 
ren sy_ideologymodel ideology
replace ideology=round(ideology)
label variable ideology "Ideology"

* Re-name and label variable from Catalist estimating the income of an individual
ren co_find income
label variable income "Income"

* Create figure 3 -- distribution of income among individuals in Catalist
twoway kdensity income, bw(20000) ylabel(0 " ", notick) xlabel(0 100000 "$100k" 200000 "$200k" 300000 "$300k" 400000 "$400k" 500000 "$500k" ) scheme(s1mono) xtitle("Income") ytitle(" ")
graph export incomedist.pdf, replace

* Create a variable that is the percentile of income for each individual
* Variable is rounded to nearest even number to ensure sufficient sample size at 
* each income level in analysis. Two individuals coded as 0 from original calculation
* are added to the group at 2.
egen incomerank=rank(income) if income~=.
egen max=max(incomerank) if incomerank~=.
gen incomepercentile=(incomerank/max)*100
replace incomepercentile=round(incomepercentile, 2)
recode incomepercentile 0=2

* Save a version of dataset to be re-used in commands that follow.  
save temp, replace

* Create regression coefficient scatter plots using income percentile. 
* These commands create Figure 4
statsby _b e(N), by( incomepercentile) clear : reg nominate ideology
label var _b_ideology "Regression coefficients" 
bysort incomepercentile: egen sample=sum(_eq2_stat_1)
twoway scatter _b_ideology incomepercentile ,  yaxis(1) xtitle("Income") aspect(1) legend(off)  title("All Individuals" ) saving(all, replace)

use temp, clear

statsby _b e(N), by(party incomepercentile) clear : reg nominate ideology
drop if incomepercentile==0
label var _b_ideology "Regression coefficients" 
bysort incomepercentile: egen sample=sum(_eq2_stat_1)
twoway scatter _b_ideology incomepercentile if party==0, mc(cranberry) yaxis(1) xtitle("Income Percentile") || scatter _b_ideology incomepercentile if party==1, mc(navy)  aspect(1) yaxis(1) legend(off)   title("By Party of MC" ) saving(byparty, replace)

* Combine the graphs produced above into one figure (Figure 4)
graph combine all.gph byparty.gph, graphr(c(white))  xcom
graph export catalistunpooled.pdf, replace


**** Supplementary analysis for Appendix ****
* This section reproduces the results for Table A1 in the Appendix

use temp, clear

* Code the income variable into four groups, low-income, middle-income, high-income, and very high income
recode incomepercentile 0/30=1 32/62=2 64/94=3 96/100=4, gen(incomegroup)

* Collapse to district level and drop missing values
collapse (mean) ideology (max) nominate, by(stateabb district party incomegroup)
drop if incomegroup==.

* Restructure data so that there is a separate variable for the mean ideology of each income group
reshape wide ideology, i(stateabb district) j(incomegroup)

* Estimate regressions showin in first 3 columns of Table A1
reg nominate ideology1 ideology2 ideology3 ideology4 
reg nominate ideology1 ideology2 ideology3 ideology4 if party==0
reg nominate ideology1 ideology2 ideology3 ideology4 if party==1


use temp, clear

* Create a measure of income percentile within each district (rather than nationall)
bysort stateabb district: egen incomerank2=rank(income) if income~=.
bysort stateabb district: egen max2=max(incomerank2) if incomerank2~=.
gen incomepercentile2=(incomerank2/max2)*100
replace incomepercentile2=round(incomepercentile2, 2)

* Code the income variable into four groups, low-income, middle-income, high-income, and very high income
recode incomepercentile2 0/30=1 32/62=2 64/94=3 96/100=4, gen(incomegroup)

* Collapse to district level and drop missing values
collapse (mean) ideology (max) nominate, by(stateabb district party incomegroup)
drop if incomegroup==.

* Restructure data so that there is a separate variable for the mean ideology of each income group
reshape wide ideology, i(stateabb district) j(incomegroup)

* Estimate regressions showin in second 3 columns of Table A1
reg nominate ideology1 ideology2 ideology3 ideology4 
reg nominate ideology1 ideology2 ideology3 ideology4 if party==0
reg nominate ideology1 ideology2 ideology3 ideology4 if party==1


