* This do-file produces the analysis from the CCES dataset

* Open the dataset that codes roll call votes for members of congress and sort
* for merging
use 2012RollCalls.dta, clear
sort inputstate cdid
save 2012RollCalls_sorted.dta, replace

* Open the 2012 CCES common content dataset. Merge in the roll call vote data. 
use CCES12_Common_VV.dta, clear
sort inputstate cdid
merge m:1 inputstate cdid using 2012RollCalls_sorted.dta

* Drop respondents who were unmerged (respondents in Washington, DC, since no House member).
drop if _m<3
drop _m

* Set survey weights
svyset [pw=weight_vv]

* Create duplicate variables for each of the "roll call" questions on the survey
gen RyanBudgetR = CC332A
gen SimpsonBowlesR = CC332B
gen MiddleClassR = CC332C
gen TaxHikePreventR = CC332D
gen KoreaTradeR = CC332F
gen RepealACAR = CC332G
gen KeystoneR = CC332H
gen DADTR = CC332J

* Recode these variables so that "don't know" or "skipped" are missing.
recode RyanBudgetR-DADTR (8/9=.)

* Recode all voters by House members on same scale as roll call vote questions
encode rollcall_A, gen(RyanBudgetMC)
recode RyanBudgetMC 1/2=. 3=2 4=1
label define RyanBudgetMC 1 "support" 2 "oppose", modify

encode rollcall_B, gen(SimpsonBowlesMC)
recode SimpsonBowlesMC 1 2 3 5 =. 4=2 6=1
label define SimpsonBowlesMC 1 "support" 2 "oppose", modify

encode rollcall_C, gen(MiddleClassMC)
recode MiddleClassMC 1/2=. 3=2 4=1
label define MiddleClassMC 1 "support" 2 "oppose", modify

encode rollcall_D, gen(TaxHikePreventMC)
recode TaxHikePreventMC 1/2=. 3=2 4=1
label define TaxHikePreventMC 1 "support" 2 "oppose", modify

encode rollcall_F, gen(KoreaTradeMC)
recode KoreaTradeMC 1/3=. 4=2 5=1
label define KoreaTradeMC 1 "support" 2 "oppose", modify

encode rollcall_G, gen(RepealACAMC)
recode RepealACAMC 1/2=. 3=2 4=1
label define RepealACAMC 1 "support" 2 "oppose", modify

encode rollcall_H, gen(KeystoneMC)
recode KeystoneMC 1 2 4=. 3=2 5=1
label define KeystoneMC 1 "support" 2 "oppose", modify

encode rollcall_J, gen(DADTMC)
recode DADTMC 1/4=. 5=2 6=1
label define DADTMC 1 "support" 2 "oppose", modify


* Create variables indicating whether R and MC agreed on each roll call vote
gen AgreeRyanBudget=1 if RyanBudgetR==RyanBudgetMC & RyanBudgetR~=. & RyanBudgetMC~=.
replace AgreeRyanBudget=0 if RyanBudgetR~=RyanBudgetMC & RyanBudgetR~=. & RyanBudgetMC~=.

gen AgreeSimpsonBowles=1 if SimpsonBowlesR==SimpsonBowlesMC & SimpsonBowlesR~=. & SimpsonBowlesMC~=.
replace AgreeSimpsonBowles=0 if SimpsonBowlesR~=SimpsonBowlesMC & SimpsonBowlesR~=. & SimpsonBowlesMC~=.

gen AgreeMiddleClass=1 if MiddleClassR==MiddleClassMC & MiddleClassR~=. & MiddleClassMC~=.
replace AgreeMiddleClass=0 if MiddleClassR~=MiddleClassMC & MiddleClassR~=. & MiddleClassMC~=.

gen AgreeTaxHike=1 if TaxHikePreventR==TaxHikePreventMC & TaxHikePreventR~=. & TaxHikePreventMC~=.
replace AgreeTaxHike=0 if TaxHikePreventR~=TaxHikePreventMC & TaxHikePreventR~=. & TaxHikePreventMC~=.

gen AgreeKoreaTrade=1 if KoreaTradeR==KoreaTradeMC & KoreaTradeR~=. & KoreaTradeMC~=.
replace AgreeKoreaTrade=0 if KoreaTradeR~=KoreaTradeMC & KoreaTradeR~=. & KoreaTradeMC~=.

gen AgreeRepealACA=1 if RepealACAR==RepealACAMC & RepealACAR~=. & RepealACAMC~=.
replace AgreeRepealACA=0 if RepealACAR~=RepealACAMC & RepealACAR~=. & RepealACAMC~=.

gen AgreeKeystone=1 if KeystoneR==KeystoneMC & KeystoneR~=. & KeystoneMC~=.
replace AgreeKeystone=0 if KeystoneR~=KeystoneMC & KeystoneR~=. & KeystoneMC~=.

gen AgreeDADT=1 if DADTR==DADTMC & DADTR~=. & DADTMC~=.
replace AgreeDADT=0 if DADTR~=DADTMC & DADTR~=. & DADTMC~=.

* Generate variable that is total number of votes on which both R and MC take a position
gen Total=1 if AgreeRyanBudget~=. 
replace Total=Total+1  if AgreeSimpsonBowles~=.
replace Total=Total+1  if AgreeMiddleClass~=.
replace Total=Total+1  if AgreeTaxHike~=.
replace Total=Total+1  if AgreeKoreaTrade~=.
replace Total=Total+1  if AgreeRepealACA~=.
replace Total=Total+1  if AgreeKeystone~=.
replace Total=Total+1  if AgreeDADT~=.

* Generate new variables which code non-answers as 0 so that agreement can be summed
recode AgreeRyanBudget .=0, gen(AgreeRyanBudget2)
recode AgreeSimpsonBowles .=0, gen(AgreeSimpsonBowles2)
recode AgreeMiddleClass .=0, gen(AgreeMiddleClass2)
recode AgreeTaxHike .=0, gen(AgreeTaxHike2)
recode AgreeKoreaTrade .=0, gen(AgreeKoreaTrade2)
recode AgreeRepealACA .=0, gen(AgreeRepealACA2)
recode AgreeKeystone .=0, gen(AgreeKeystone2)
recode AgreeDADT .=0, gen(AgreeDADT2)

* Sum number of votes on which R and MC agreed, then divide by total roll call 
* questions that R answered and on which MC voted. This creates the main Dependent Variable.
gen TotalAgree=AgreeRyanBudget2+AgreeSimpsonBowles2+AgreeMiddleClass2+AgreeTaxHike2+AgreeKoreaTrade2+AgreeRepealACA2+AgreeKeystone2+AgreeDADT2
gen ProportionAgree=TotalAgree/Total

* Recode family income measure so that they reflect income percentiles rather than 
* total income. 
recode faminc 1=0 2=7 3=18 4=29 5=39 6=49 7=57 8=64 9=70 10=79 11=85 12=91 13=95 14=97 15=98 16=99 32=97 97=., gen(FamilyIncome2)

* Create dummy variable for whether R's House member is Republican (0) or Democrat (1)
encode(CurrentHouseParty), gen(CurrentHouseMCParty)
recode CurrentHouseMCParty 2=0 3=. 
label define CurrentHouseMCParty 0 "Republican" 1 "Democrat", modify

* Estimate three basic regressions to recover proportion of agreement at each 
* income level. Then plot agreement against income for paper. 
svy: regress ProportionAgree i.FamilyIncome2 
margins, over(FamilyIncome2)
marginsplot, aspect(1) scheme(s1color) ytitle("Proportion of roll calls on which R and MC Agree") xtitle("Income (percentile)")  title("All Respondents Combined") ci1(msize(0) lw(thin) lc(black)) plotop(lc(none) mc(black)) xlabel(0(20)100) saving(combinedpercentile, replace)

svy: regress ProportionAgree i.FamilyIncome2 if CurrentHouseMCParty==0 
margins, over(FamilyIncome2)
marginsplot, aspect(1) scheme(s1color) ytitle("Proportion of roll calls on which R and MC Agree") xtitle("Income (percentile)")  title("Republican Incumbent") xlabel(0(20)100) saving(republicans, replace) plot1(mc(cranberry) lc(none)) ci1(lc(cranberry) lw(thin) msize(0))  legend(off) 

svy: regress ProportionAgree i.FamilyIncome2 if CurrentHouseMCParty==1 
margins, over(FamilyIncome2)
marginsplot, aspect(1) scheme(s1color) ytitle("Proportion of roll calls on which R and MC Agree") xtitle("Income (percentile)")  title("Democratic Incumbent") xlabel(0(20)100) saving(democrats, replace) plot1(mc(navy) lc(none)) ci1(lc(navy) lw(thin) msize(0))  legend(off) 

* Collect all three plots into one graph for paper
graph combine combinedpercentile.gph republicans.gph democrats.gph , graphr(c(white)) iscale(.55) row(1) ycom
graph export cces2012pooled.pdf, replace

